@@ -1,24 +1,5 @@
-/* Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2021 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; version 2
-  of the License.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-only
+// Copyright The XCSoar Project
 
 package org.xcsoar;
 
@@ -38,6 +19,7 @@ import android.content.Intent;
 import android.content.IntentFilter;
 import android.hardware.usb.UsbDevice;
 import android.hardware.usb.UsbManager;
+import android.hardware.usb.UsbConstants;
 import android.os.Build;
 import android.util.Log;
 
@@ -180,7 +162,7 @@ public final class UsbSerialHelper extends BroadcastReceiver {
     }
 
     public synchronized void permissionGranted() {
-      if (!port.isOpen())
+      if (port != null && !port.isOpen())
         port.open(usbmanager, device, iface);
     }
 
@@ -318,9 +300,12 @@ public final class UsbSerialHelper extends BroadcastReceiver {
         /* still exists */
         continue;
 
-      UsbDeviceInterface deviface = new UsbDeviceInterface(device, iface);
-      interfaces.add(deviface);
-      broadcastDetectedDeviceInterface(deviface);
+      int iclass = device.getInterface(iface).getInterfaceClass();
+      if (iclass == UsbConstants.USB_CLASS_VENDOR_SPEC || iclass == UsbConstants.USB_CLASS_CDC_DATA) {
+        UsbDeviceInterface deviface = new UsbDeviceInterface(device, iface);
+        interfaces.add(deviface);
+        broadcastDetectedDeviceInterface(deviface);
+      }
     }
   }
 
@@ -377,7 +362,7 @@ public final class UsbSerialHelper extends BroadcastReceiver {
     PendingIntent pi =
       PendingIntent.getBroadcast(context, 0,
                                  new Intent(UsbSerialHelper.ACTION_USB_PERMISSION),
-                                 0);
+                                 PendingIntent.FLAG_IMMUTABLE);
 
     usbmanager.requestPermission(device, pi);
   }
