@@ -213,21 +213,21 @@ FlarmDevice::ReadFlightInfo(RecordedFlightInfo &flight,
                             OperationEnvironment &env)
 {
   // Create header for getting record information
-  FLARM::FrameHeader header = PrepareFrameHeader(FLARM::MT_GETRECORDINFO);
+  FLARM::FrameHeader header = PrepareFrameHeader(FLARM::MessageType::GETRECORDINFO);
 
   // Send request
   SendStartByte();
   SendFrameHeader(header, env, std::chrono::seconds(1));
 
   // Wait for an answer and save the payload for further processing
-  AllocatedArray<uint8_t> data;
+  AllocatedArray<std::byte> data;
   uint16_t length;
-  uint8_t ack_result =
+  const auto ack_result =
     WaitForACKOrNACK(header.sequence_number, data, length,
                      env, std::chrono::seconds(5));
 
   // If neither ACK nor NACK was received
-  if (ack_result != FLARM::MT_ACK || length <= 2)
+  if (ack_result != FLARM::MessageType::ACK || length <= 2)
     return false;
 
   char *record_info = (char *)data.data() + 2;
@@ -238,14 +238,14 @@ FLARM::MessageType
 FlarmDevice::SelectFlight(uint8_t record_number, OperationEnvironment &env)
 {
   // Create header for selecting a log record
-  uint8_t data[1] = { record_number };
-  FLARM::FrameHeader header = PrepareFrameHeader(FLARM::MT_SELECTRECORD,
-                                                 data, sizeof(data));
+  std::byte data[] = { static_cast<std::byte>(record_number) };
+  FLARM::FrameHeader header = PrepareFrameHeader(FLARM::MessageType::SELECTRECORD,
+                                                 std::span{data});
 
   // Send request
   SendStartByte();
   SendFrameHeader(header, env, std::chrono::seconds(1));
-  SendEscaped(data, sizeof(data), env, std::chrono::seconds(1));
+  SendEscaped(std::span{data}, env, std::chrono::seconds(1));
 
   // Wait for an answer
   return WaitForACKOrNACK(header.sequence_number,
@@ -265,11 +265,11 @@ FlarmDevice::ReadFlightList(RecordedFlightList &flight_list,
       FLARM::MessageType ack_result = SelectFlight(i, env);
 
       // Last record reached -> bail out and return list
-      if (ack_result == FLARM::MT_NACK)
+      if (ack_result == FLARM::MessageType::NACK)
         break;
 
       // If neither ACK nor NACK was received
-      if (ack_result != FLARM::MT_ACK) {
+      if (ack_result != FLARM::MessageType::ACK) {
         mode = Mode::UNKNOWN;
         return false;
       }
@@ -293,17 +293,18 @@ FlarmDevice::DownloadFlight(Path path, OperationEnvironment &env)
   env.SetProgressRange(100);
   while (true) {
     // Create header for getting IGC file data
-    FLARM::FrameHeader header = PrepareFrameHeader(FLARM::MT_GETIGCDATA);
+    FLARM::FrameHeader header = PrepareFrameHeader(FLARM::MessageType::GETIGCDATA);
 
     // Send request
     SendStartByte();
     SendFrameHeader(header, env, std::chrono::seconds(1));
 
     // Wait for an answer and save the payload for further processing
-    AllocatedArray<uint8_t> data;
+    AllocatedArray<std::byte> data;
     uint16_t length;
     bool ack = WaitForACKOrNACK(header.sequence_number, data,
-                                length, env, std::chrono::seconds(10)) == FLARM::MT_ACK;
+                                length, env,
+                                std::chrono::seconds(10)) == FLARM::MessageType::ACK;
 
     // If no ACK was received
     if (!ack || length <= 3)
@@ -312,8 +313,8 @@ FlarmDevice::DownloadFlight(Path path, OperationEnvironment &env)
     length -= 3;
 
     // Read progress (in percent)
-    uint8_t progress = *(data.begin() + 2);
-    env.SetProgressPosition(std::min((unsigned)progress, 100u));
+    const auto progress = static_cast<unsigned>(data[2]);
+    env.SetProgressPosition(std::min(progress, 100u));
 
     const char last_char = (char)data.back();
     bool is_last_packet = (last_char == 0x1A);
@@ -321,8 +322,7 @@ FlarmDevice::DownloadFlight(Path path, OperationEnvironment &env)
       length--;
 
     // Read IGC data
-    const char *igc_data = (const char *)data.data() + 3;
-    os.Write(igc_data, length);
+    os.Write({data.data() + 3, length});
 
     if (is_last_packet)
       break;
@@ -345,7 +345,7 @@ FlarmDevice::DownloadFlight(const RecordedFlightInfo &flight,
   FLARM::MessageType ack_result = SelectFlight(flight.internal.flarm, env);
 
   // If no ACK was received -> cancel
-  if (ack_result != FLARM::MT_ACK)
+  if (ack_result != FLARM::MessageType::ACK)
     return false;
 
   try {
