@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2022 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "TaskDialogs.hpp"
 #include "Dialogs/WidgetDialog.hpp"
@@ -130,14 +110,12 @@ AlternatesListWidget::CreateButtons(WidgetDialog &dialog)
     auto const &waypoint = GetSelectedWaypoint();
     ActionInterface::SetActiveFrequency(waypoint.radio_frequency,
                                         waypoint.name.c_str());
-    cancel_button->Click();
   });
 
   dialog.AddButton(_("Set Standby Frequency"), [this](){
     auto const &waypoint = GetSelectedWaypoint();
     ActionInterface::SetStandbyFrequency(waypoint.radio_frequency,
                                          waypoint.name.c_str());
-    cancel_button->Click();
   });
 
   cancel_button = dialog.AddButton(_("Close"), mrCancel);
