@@ -11,7 +11,6 @@
 #include "ui/canvas/RawBitmap.hpp"
 #include "Renderer/GeoBitmapRenderer.hpp"
 #include "Projection/WindowProjection.hpp"
-#include "Asset.hpp"
 #include "ui/event/Idle.hpp"
 
 #include <cassert>
@@ -22,9 +21,8 @@
  *
  * i must be below or equal to 128.
  */
-constexpr
-static inline unsigned
-MIX(unsigned x, unsigned y, unsigned i)
+static constexpr unsigned
+MIX(unsigned x, unsigned y, unsigned i) noexcept
 {
   return (x * i + y * ((1 << 7) - i)) >> 7;
 }
@@ -37,9 +35,8 @@ MIX(unsigned x, unsigned y, unsigned i)
  * illum > 0:  Highlight, mixed with up to 25% yellow
  * illum = 0:  No shading
  */
-[[gnu::const]]
-inline RawColor
-TerrainShading(const int illum, RGB8Color color)
+static constexpr RawColor
+TerrainShading(const int illum, RGB8Color color) noexcept
 {
   if (illum == -64) {
     // brown color mixed in for contours
@@ -62,9 +59,8 @@ TerrainShading(const int illum, RGB8Color color)
     return RawColor(color.Red(), color.Green(), color.Blue());
 }
 
-[[gnu::const]]
-static unsigned
-ContourInterval(const unsigned h, const unsigned contour_height_scale)
+static constexpr unsigned
+ContourInterval(unsigned h, unsigned contour_height_scale) noexcept
 {
   return std::min(254u, h >> contour_height_scale);
 }
@@ -79,16 +75,9 @@ ContourInterval(const TerrainHeight h, const unsigned contour_height_scale)
   return ContourInterval(h.GetValue(), contour_height_scale);
 }
 
-RasterRenderer::RasterRenderer()
-{
-  // scale quantisation_pixels so resolution is not too high on old hardware
-  // with large displays
-  if (IsAncientHardware())
-    quantisation_pixels = Layout::FastScale(quantisation_pixels);
-}
+RasterRenderer::RasterRenderer() noexcept = default;
 
-
-RasterRenderer::~RasterRenderer()
+RasterRenderer::~RasterRenderer() noexcept
 {
   delete[] color_table;
   delete image;
@@ -99,7 +88,7 @@ RasterRenderer::~RasterRenderer()
 
 [[gnu::pure]]
 static unsigned
-GetQuantisation()
+GetQuantisation() noexcept
 {
   if (IsUserIdle(2000))
     /* full terrain resolution when the user is idle */
@@ -114,14 +103,14 @@ GetQuantisation()
 }
 
 bool
-RasterRenderer::UpdateQuantisation()
+RasterRenderer::UpdateQuantisation() noexcept
 {
   quantisation_pixels = GetQuantisation();
   return quantisation_pixels < last_quantisation_pixels;
 }
 
 const GLTexture &
-RasterRenderer::BindAndGetTexture() const
+RasterRenderer::BindAndGetTexture() const noexcept
 {
   return image->BindAndGetTexture();
 }
@@ -129,7 +118,8 @@ RasterRenderer::BindAndGetTexture() const
 #endif
 
 void
-RasterRenderer::ScanMap(const RasterMap &map, const WindowProjection &projection)
+RasterRenderer::ScanMap(const RasterMap &map,
+                        const WindowProjection &projection) noexcept
 {
   // Coordinates of the MapWindow center
   const auto p = projection.GetScreenCenter();
@@ -168,8 +158,7 @@ RasterRenderer::ScanMap(const RasterMap &map, const WindowProjection &projection
   bounds.IntersectWith(map.GetBounds());
 
   height_matrix.Fill(map, bounds,
-                     projection.GetScreenSize().width / quantisation_pixels,
-                     projection.GetScreenSize().height / quantisation_pixels,
+                     (UnsignedPoint2D)projection.GetScreenSize() / quantisation_pixels,
                      true);
 
   last_quantisation_pixels = quantisation_pixels;
@@ -183,16 +172,16 @@ RasterRenderer::GenerateImage(bool do_shading,
                               unsigned height_scale,
                               int contrast, int brightness,
                               const Angle sunazimuth,
-                              bool do_contour)
+                              bool do_contour) noexcept
 {
   if (image == nullptr ||
-      height_matrix.GetWidth() > image->GetSize().width ||
-      height_matrix.GetHeight() > image->GetSize().height) {
+      height_matrix.GetSize().x > image->GetSize().width ||
+      height_matrix.GetSize().y > image->GetSize().height) {
     delete image;
-    image = new RawBitmap({height_matrix.GetWidth(), height_matrix.GetHeight()});
+    image = new RawBitmap(PixelSize{height_matrix.GetSize()});
 
     delete[] contour_column_base;
-    contour_column_base = new unsigned char[height_matrix.GetWidth()];
+    contour_column_base = new unsigned char[height_matrix.GetSize().x];
   }
 
   if (quantisation_effective == 0) {
@@ -214,21 +203,21 @@ RasterRenderer::GenerateImage(bool do_shading,
 }
 
 void
-RasterRenderer::GenerateUnshadedImage(unsigned height_scale,
-                                      const unsigned contour_height_scale)
+RasterRenderer::GenerateUnshadedImage(const unsigned height_scale,
+                                      const unsigned contour_height_scale) noexcept
 {
   const auto *src = height_matrix.GetData();
   const RawColor *oColorBuf = color_table + 64 * 256;
   RawColor *dest = image->GetTopRow();
 
-  for (unsigned y = height_matrix.GetHeight(); y > 0; --y) {
+  for (unsigned y = height_matrix.GetSize().y; y > 0; --y) {
     RawColor *p = dest;
     dest = image->GetNextRow(dest);
 
     unsigned contour_row_base = ContourInterval(*src, contour_height_scale);
     unsigned char *contour_this_column_base = contour_column_base;
 
-    for (unsigned x = height_matrix.GetWidth(); x > 0; --x) {
+    for (unsigned x = height_matrix.GetSize().x; x > 0; --x) {
       const auto e = *src++;
       if (gcc_likely(!e.IsSpecial())) {
         unsigned h = std::max(0, (int)e.GetValue());
@@ -264,16 +253,14 @@ RasterRenderer::GenerateUnshadedImage(unsigned height_scale,
  * GenerateSlopeImage() formula when the map file is broken, avoiding
  * the sqrt() call with a negative argument.
  */
-[[gnu::const]]
-static int
-ClipHeightDelta(int d)
+static constexpr int
+ClipHeightDelta(int d) noexcept
 {
   return Clamp(d, -512, 512);
 }
 
-[[gnu::const]]
-static int
-ClipHeightDelta(TerrainHeight a, TerrainHeight b)
+static constexpr int
+ClipHeightDelta(TerrainHeight a, TerrainHeight b) noexcept
 {
   return ClipHeightDelta(a.GetValue() - b.GetValue());
 }
@@ -287,15 +274,12 @@ void
 RasterRenderer::GenerateSlopeImage(unsigned height_scale,
                                    int contrast,
                                    const int sx, const int sy, const int sz,
-                                   const unsigned contour_height_scale)
+                                   const unsigned contour_height_scale) noexcept
 {
   assert(quantisation_effective > 0);
 
-  PixelRect border;
-  border.left = quantisation_effective;
-  border.top = quantisation_effective;
-  border.right = height_matrix.GetWidth() - quantisation_effective;
-  border.bottom = height_matrix.GetHeight() - quantisation_effective;
+  const auto border = PixelRect{PixelSize{height_matrix.GetSize()}}
+    .WithPadding(quantisation_effective);
 
   const unsigned height_slope_factor =
     Clamp((unsigned)pixel_size, 1u,
@@ -309,15 +293,15 @@ RasterRenderer::GenerateSlopeImage(unsigned height_scale,
 
   RawColor *dest = image->GetTopRow();
 
-  for (unsigned y = 0; y < height_matrix.GetHeight(); ++y) {
+  for (unsigned y = 0; y < height_matrix.GetSize().y; ++y) {
     const unsigned row_plus_index = y < (unsigned)border.bottom
       ? quantisation_effective
-      : height_matrix.GetHeight() - 1 - y;
-    const unsigned row_plus_offset = height_matrix.GetWidth() * row_plus_index;
+      : height_matrix.GetSize().y - 1 - y;
+    const unsigned row_plus_offset = height_matrix.GetSize().x * row_plus_index;
 
     const unsigned row_minus_index = y >= quantisation_effective
       ? quantisation_effective : y;
-    const unsigned row_minus_offset = height_matrix.GetWidth() * row_minus_index;
+    const unsigned row_minus_offset = height_matrix.GetSize().x * row_minus_index;
 
     const unsigned p31 = row_plus_index + row_minus_index;
 
@@ -327,7 +311,7 @@ RasterRenderer::GenerateSlopeImage(unsigned height_scale,
     unsigned contour_row_base = ContourInterval(*src, contour_height_scale);
     unsigned char *contour_this_column_base = contour_column_base;
 
-    for (unsigned x = 0; x < height_matrix.GetWidth(); ++x, ++src) {
+    for (unsigned x = 0; x < height_matrix.GetSize().x; ++x, ++src) {
       const auto e = *src;
       if (gcc_likely(!e.IsSpecial())) {
         unsigned h = std::max(0, (int)e.GetValue());
@@ -349,7 +333,7 @@ RasterRenderer::GenerateSlopeImage(unsigned height_scale,
 
         const unsigned column_plus_index = x < (unsigned)border.right
           ? quantisation_effective
-          : height_matrix.GetWidth() - 1 - x;
+          : height_matrix.GetSize().x - 1 - x;
         const unsigned column_minus_index = x >= (unsigned)border.left
           ? quantisation_effective : x;
 
@@ -418,7 +402,7 @@ void
 RasterRenderer::GenerateSlopeImage(unsigned height_scale,
                                    int contrast, int brightness,
                                    const Angle sunazimuth,
-                                   const unsigned contour_height_scale)
+                                   const unsigned contour_height_scale) noexcept
 {
   const Angle fudgeelevation = Angle::Degrees(10) +
     Angle::Degrees(80.0 / 255.0) * brightness;
@@ -433,7 +417,7 @@ RasterRenderer::GenerateSlopeImage(unsigned height_scale,
 
 void
 RasterRenderer::PrepareColorTable(const ColorRamp *color_ramp, bool do_water,
-                                  unsigned height_scale, int interp_levels)
+                                  unsigned height_scale, int interp_levels) noexcept
 {
   if (color_table == nullptr)
     color_table = new RawColor[256 * 128];
@@ -466,29 +450,28 @@ RasterRenderer::PrepareColorTable(const ColorRamp *color_ramp, bool do_water,
 }
 
 void
-RasterRenderer::ContourStart(const unsigned contour_height_scale)
+RasterRenderer::ContourStart(const unsigned contour_height_scale) noexcept
 {
   // initialise column to first row
   const auto *src = height_matrix.GetData();
   unsigned char *col_base = contour_column_base;
-  for (unsigned x = height_matrix.GetWidth(); x > 0; --x)
+  for (unsigned x = height_matrix.GetSize().x; x > 0; --x)
     *col_base++ = ContourInterval(*src++, contour_height_scale);
 }
 
 void
 RasterRenderer::Draw([[maybe_unused]] Canvas &canvas,
                      const WindowProjection &projection,
-                     [[maybe_unused]] bool transparent_white) const
+                     [[maybe_unused]] bool transparent_white) const noexcept
 {
 #ifdef ENABLE_OPENGL
   if (bounds.IsValid() && bounds.Overlaps(projection.GetScreenBounds()))
     DrawGeoBitmap(*image,
-                  PixelSize(height_matrix.GetWidth(),
-                            height_matrix.GetHeight()),
+                  PixelSize{height_matrix.GetSize()},
                   bounds,
                   projection);
 #else
-  image->StretchTo({height_matrix.GetWidth(), height_matrix.GetHeight()},
+  image->StretchTo(PixelSize{height_matrix.GetSize()},
                    canvas, projection.GetScreenSize(),
                    transparent_white);
 #endif
