@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2022 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #pragma once
 
@@ -46,6 +26,7 @@ struct StaticEnumChoice;
 class Angle;
 class RoughTime;
 class RoughTimeDelta;
+class Path;
 class Button;
 
 /**
@@ -569,7 +550,18 @@ public:
     return &df == &GetDataField(i);
   }
 
+  /**
+   * Load a value into a #DataFieldInteger.
+   */
   void LoadValue(unsigned i, int value) noexcept;
+
+  /**
+   * Load an unsigned value into a #DataFieldInteger.
+   */
+  void LoadValue(unsigned i, unsigned value) noexcept {
+    LoadValue(i, static_cast<int>(value));
+  }
+
   void LoadValue(unsigned i, bool value) noexcept;
   void LoadValueEnum(unsigned i, const TCHAR *text) noexcept;
   void LoadValueEnum(unsigned i, unsigned value) noexcept;
@@ -588,6 +580,8 @@ public:
 
   void LoadValue(unsigned i, RoughTime value) noexcept;
 
+  void LoadValue(unsigned i, Path value) noexcept;
+
   /**
    * Load a value into a control created by AddDuration().
    */
@@ -634,6 +628,9 @@ public:
   [[gnu::pure]]
   RoughTime GetValueRoughTime(unsigned i) const noexcept;
 
+  [[gnu::pure]]
+  Path GetValueFile(unsigned i) const noexcept;
+
   [[gnu::pure]]
   const TCHAR *GetValueString(unsigned i) const noexcept {
     return GetDataField(i).GetAsString();
