@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2021 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "ui/canvas/custom/TopCanvas.hpp"
 #include "ui/canvas/Canvas.hpp"
@@ -179,7 +159,9 @@ TopCanvas::TopCanvas(UI::Display &_display)
   case KoboModel::GLO_HD:
   case KoboModel::AURA2:
   case KoboModel::CLARA_HD:
+  case KoboModel::CLARA_2E:
   case KoboModel::LIBRA2:
+  case KoboModel::LIBRA_H2O:
     frame_sync = true;
     break;
 
@@ -283,6 +265,7 @@ TopCanvas::Flip()
 
   epd_update_marker++;
 
+  KoboModel kobo_model = DetectKoboModel();
   struct mxcfb_update_data epd_update_data = {
     {
       0, 0, buffer.width, buffer.height
@@ -290,11 +273,13 @@ TopCanvas::Flip()
 
     uint32_t(enable_dither &&
              (/* use A2 mode only on some Kobo models */
-              DetectKoboModel() == KoboModel::TOUCH2 ||
-              DetectKoboModel() == KoboModel::GLO_HD ||
-              DetectKoboModel() == KoboModel::AURA2 ||
-              DetectKoboModel() == KoboModel::LIBRA2 ||
-              DetectKoboModel() == KoboModel::CLARA_HD)
+              kobo_model == KoboModel::TOUCH2 ||
+              kobo_model == KoboModel::GLO_HD ||
+              kobo_model == KoboModel::AURA2 ||
+              kobo_model == KoboModel::LIBRA2 ||
+              kobo_model == KoboModel::LIBRA_H2O ||
+              kobo_model == KoboModel::CLARA_HD ||
+              kobo_model == KoboModel::CLARA_2E)
              ? WAVEFORM_MODE_A2
              : WAVEFORM_MODE_AUTO),
     UPDATE_MODE_FULL, // PARTIAL
